@@ -188,8 +188,12 @@ def aoti_blocks_load(module: torch.nn.Module, repo_id: str, variant: str | None
         raise RuntimeError("aoti_blocks_load only works with modules that expose _repeated_blocks")
 
     repeated_blocks = cast(list[str], repeated_blocks)
-    block_names = [name if variant is None else f'{name}.{variant}' for name in repeated_blocks]
-    aoti_files = {name: hf_hub_download(repo_id, 'package.pt2', subfolder=name) for name in block_names}
+    aoti_files = {name: hf_hub_download(
+        repo_id=repo_id,
+        filename='package.pt2',
+        subfolder=name if variant is None else f'{name}.{variant}',
+    ) for name in repeated_blocks}
+
     for block_name, aoti_file in aoti_files.items():
         for block in module.modules():
             if block.__class__.__name__ == block_name:
